@@ -35,10 +35,11 @@ data Cmd = Cmd
     ,cmdColor :: Bool                -- ^ color the result
     ,cmdCpp :: CppFlags              -- ^ options for CPP
     ,cmdDataDir :: FilePath          -- ^ the data directory
-    ,cmdEncoding :: Encoding           -- ^ the text encoding
+    ,cmdEncoding :: Encoding         -- ^ the text encoding
     ,cmdFindHints :: [FilePath]      -- ^ source files to look for hints in
     ,cmdLanguage :: [Extension]      -- ^ the extensions (may be prefixed by "No")
     ,cmdQuiet :: Bool                -- ^ supress all console output
+    ,cmdCross :: Bool                -- ^ work between source files
     }
 
 
@@ -59,6 +60,7 @@ data Opts = Help
           | FindHints FilePath
           | Language String
           | Quiet
+          | Cross
             deriving Eq
 
 
@@ -73,6 +75,7 @@ opts = [Option "?" ["help"] (NoArg Help) "Display help message"
        ,Option "X" ["language"] (ReqArg Language "lang") "Language extensions (Arrows, NoCPP)"
        ,Option "u" ["utf8"] (NoArg $ Encoding "UTF-8") "Use UTF-8 text encoding"
        ,Option ""  ["encoding"] (ReqArg Encoding "encoding") "Choose the text encoding"
+       ,Option "x" ["cross"] (NoArg Cross) "Work between modules"
        ,Option "f" ["find"] (ReqArg FindHints "file") "Find hints in a Haskell file"
        ,Option "t" ["test"] (NoArg Test) "Run in test mode"
        ,Option "d" ["datadir"] (ReqArg DataDir "dir") "Override the data directory"
@@ -137,6 +140,7 @@ getCmd args = do
         ,cmdFindHints = findHints
         ,cmdLanguage = languages
         ,cmdQuiet = Quiet `elem` opt
+        ,cmdCross = Cross `elem` opt
         }
 
 
