@@ -75,21 +75,23 @@ dotVersion _ = Nothing
 ---------------------------------------------------------------------
 -- PERFORM THE MATCHING
 
-findIdeas :: [Setting] -> NameMatch -> Module S -> Decl_ -> [Idea]
-findIdeas matches nm _ decl =
-  [ idea (rankS m) (hintS m) x y
-  | (parent,x) <- universeParentExp decl, not $ isParen x, let x2 = fmapAn x
-  , m <- matches, Just y <- [matchIdea nm decl m parent x2]]
+findIdeas :: [Setting] -> Scope -> Module S -> Decl_ -> [Idea]
+findIdeas matches s _ decl =
+  [ (idea (severityS m) (hintS m) x y){note=notes}
+  | decl <- case decl of InstDecl{} -> children decl; _ -> [decl]
+  , (parent,x) <- universeParentExp decl, not $ isParen x, let x2 = fmapAn x
+  , m <- matches, Just (y,notes) <- [matchIdea s decl m parent x2]]
 
 
-matchIdea :: NameMatch -> Decl_ -> Setting -> Maybe (Int, Exp_) -> Exp_ -> Maybe Exp_
-matchIdea nm decl MatchExp{lhs=lhs,rhs=rhs,side=side} parent x = do
+matchIdea :: Scope -> Decl_ -> Setting -> Maybe (Int, Exp_) -> Exp_ -> Maybe (Exp_,String)
+matchIdea s decl MatchExp{lhs=lhs,rhs=rhs,side=side,scope=scope,notes=notes} parent x = do
+    let nm = nameMatch scope s
     u <- unifyExp nm lhs x
     u <- check u
-    let res = addBracket parent $ unqualify nm $ performEval $ subst u rhs
+    let res = addBracket parent $ unqualify scope s u $ performEval $ subst u rhs
     guard $ checkSide side $ ("original",x) : ("result",res) : u
     guard $ checkDefine decl parent res
-    return res
+    return (res,notes)
 
 
 ---------------------------------------------------------------------
@@ -110,6 +112,9 @@ unifyDef nm x y = fmap concat . sequence =<< gzip (unify nm) x y
 unifyExp :: NameMatch -> Exp_ -> Exp_ -> Maybe [(String,Exp_)]
 unifyExp nm x y | isParen x || isParen y = unifyExp nm (fromParen x) (fromParen y)
 unifyExp nm (Var _ (fromNamed -> v)) y | isUnifyVar v = Just [(v,y)]
+unifyExp nm (Var _ (Qual _ (ModuleName _ [m]) x)) (Var _ y)
+    | Qual _ (ModuleName _ m2) y <- y, y == x = Just [([m], Var an $ UnQual an $ Ident an m2)]
+    | UnQual _ y <- y, y == x = Just [([m], Var an $ UnQual an $ Ident an "")]
 unifyExp nm (Var _ x) (Var _ y) | nm x y = Just []
 unifyExp nm x@(App _ x1 x2) (App _ y1 y2) =
     liftM2 (++) (unifyExp nm x1 y1) (unifyExp nm x2 y2) `mplus`
@@ -170,13 +175,17 @@ checkSide x bind = maybe True f x
 
         f (App _ cond (sub -> y))
             | 'i':'s':typ <- fromNamed cond
-            = if typ == "Atom" then isAtom y else head (words $ show y) == typ
+            = isType typ y
         f (App _ (App _ cond (sub -> x)) (sub -> y))
             | cond ~= "notIn" = and [x `notElem` universe y | x <- list x, y <- list y]
             | cond ~= "notEq" = x /= y
         f x | x ~= "notTypeSafe" = True
         f x = error $ "Hint.Match.checkSide, unknown side condition: " ++ prettyPrint x
 
+        isType "Atom" x = isAtom x
+        isType ('L':'i':'t':typ@(_:_)) (Lit _ x) = head (words $ show x) == typ
+        isType typ x = head (words $ show x) == typ
+
         list :: Exp_ -> [Exp_]
         list (List _ xs) = xs
         list x = [x]
@@ -203,11 +212,13 @@ performEval x = x
 
 
 -- contract Data.List.foo ==> foo, if Data.List is loaded
-unqualify :: NameMatch -> Exp_ -> Exp_
-unqualify nm = transformBi f
+-- change X.foo => Module.foo, where X is looked up in the subst
+unqualify :: Scope -> Scope -> [(String,Exp_)] -> Exp_ -> Exp_
+unqualify from to subs = transformBi f
     where
-        f (Qual _ mod x) | nm (Qual an mod x) (UnQual an x) = UnQual an x
-        f x = x
+        f (Qual _ (ModuleName _ [m]) x) | Just y <- fmap fromNamed $ lookup [m] subs
+            = if null y then UnQual an x else Qual an (ModuleName an y) x
+        f x = nameQualify from to x
 
 
 addBracket :: Maybe (Int,Exp_) -> Exp_ -> Exp_
