@@ -138,7 +138,7 @@ checkAnnotations setting file = do
     return $ Result (length failures) (length tests)
     where
         f (Test loc inp out) = do
-            ideas <- applyHintStr parseFlags setting file inp
+            ideas <- applyHintString parseFlags setting file inp
             let good = case out of
                     Nothing -> null ideas
                     Just x -> length ideas == 1 &&
@@ -201,7 +201,7 @@ checkInputOutput main xs = do
         else error "checkInputOutput, couldn't find or figure out flags"
 
     got <- fmap (fmap lines) $ captureOutput $
-        handle (\(e::SomeException) -> print $ e) $
+        handle (\(e::SomeException) -> print e) $
         handle (\(e::ExitCode) -> return ()) $
         main flags
     want <- fmap lines $ reader "output"
